Lua_GoFishingShopWindow = class("Lua_GoFishingShopWindow", Lua_Window)
function Lua_GoFishingShopWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GoFishingShopWindow";
	self.skinName = "GoFishingShopWindow_skin";
	self.isFullSizeWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/gofishing/xui_cdzj_bg_02.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_GoFishingShopWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	self.shopType = Lua_ShopData.GOFISHING_SHOP;
	self.moneyList = Array();

	self.itemList = Lua_DragList.new(self.content, 628, 880 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList.tweenId = 2013;
	self.itemList:setListCell(Lua_GoFishingShopItem, 196, 257, 3);
	self.itemList:setLocation(0, -120, 0);
	self.itemList:setCellSpacing(20, 20);

	self:addLuaEvent("UPDATE_SHOP_INFO", self, self.updateServerInfo);
	self:updateShowInfo();
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sShopInfo(self.shopType);
end

function Lua_GoFishingShopWindow:dispose()
	if self.moneyList then
		self.moneyList:dispose();
		self.moneyList:clear();
		self.moneyList = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	DataCenter.shopData:dispose();
	self:superCall("dispose");
end

function Lua_GoFishingShopWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.itemList:setContentRect(628, 880 + self.adaptHeight);
end

function Lua_GoFishingShopWindow:updateShowInfo()
	local vo = DataCenter.shopUtil:getShopTypeVo(self.shopType);
	local list = vo.moneyType;
	local num = list == nil and 0 or #list;
	local len = self.moneyList:getSize();
	local maxLen = num > len and num or len;
	local item;
	for i = 1, maxLen do
		item = self.moneyList[i];
		if i > num then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_MoneyItem.new(self.content);
				self.moneyList:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(1);
			item:setLocation(249 - (i - 1) * 190, -26, 0);
			item:setCanClick(true);
			item:setMoney(list[i]);
		end
	end
end

function Lua_GoFishingShopWindow:updateServerInfo()
	local list = DataCenter.shopData:getCurShopItemList(self.shopType);
	self.itemList:setArrayData(list);
end










Lua_GoFishingShopItem = class("Lua_GoFishingShopItem", Lua_ListCell)
function Lua_GoFishingShopItem:ctor(p)
	self:superCall("ctor", p, "GoFishingShopItem_skin");
end

function Lua_GoFishingShopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setCanClick(false);
	self.itemIcon:setSiblingIndex(1);
	self.itemIcon:setLocation(0, 31.5, 0);
end

function Lua_GoFishingShopItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_GoFishingShopItem:setData(data)
	self.data = data;
	self.itemIcon:setData(data.itemVo);
	self.nameText.text = data.name;

	self.sellOutObj:SetActive(data.isSoldOut);
	if data.discount > 0 then
		self.discountIcon:setEnable(true);
		self.discountIcon:setAltas("shop_atlas_1", "xui_sd_label_"..data.discount);
	else
		self.discountIcon:setEnable(false);
	end
	self.deserveIcon:setEnable(data.deserve == 1);

	if data.moneyCount > 0 then
		local config = getConfig("item", data.moneyType);
		self.costIcon:setAltas(config.icon_atlas, config.icon_sprite);

		if DataCenter.packData:getItemCountById(data.moneyType) < data.moneyCount then
			self.costCount.text = LanUtil.formateStr(125045, numberTrans(data.moneyCount));
		else
			self.costCount.text = numberTrans(data.moneyCount);
		end
	else
		self.costCount:setLangValue(125011);
	end
	self.costCount:resetSize();
	local width = 50 + self.costCount.width;
	LuaUtil.setObjPos(self.costObject, -width / 2, -97.5, 0);
end

function Lua_GoFishingShopItem:onPressClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.itemIcon:checkInBound(winPos.x, winPos.y) then
		DataCenter.packUtil:showItemInfo(self.data.itemVo);
		return;
	end

	if self.data.isSoldOut then
		OperateAlert.showLangValue(125014);
	elseif self.data.vip_level > DataCenter.roleData.vip then
		OperateAlert.showLangValue(125021);
	else
		if DataCenter.moneyData:isMoneyEnough(self.data.moneyType, self.data.moneyCount, true, true) then
			local param = {
				id = self.data.itemId, -- 购买道具id
				itemCount = self.data.itemAmount, -- 购买一份商品所携带的数量
				limitCount = self.data.leftTimes, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
				costId = self.data.moneyType, -- 消耗道具id
				costCount = self.data.moneyCount, -- 消耗道具数量
				tipStr = "",
				isShowTipWindow = false, -- 点击购买按钮时，是否显示提示窗口
				isLimitBtn = false, -- 最小、最大、-、+按钮是否可点击
				isShowBackBtn = false, -- 是否显示返回按钮
				cancelBtnStr = LanUtil.getValue(125051), -- 默认取消
				sureBtnStr = LanUtil.getValue(125052), -- 默认确定
				owner = self, 
				callFunc = self.onSureBuy, -- 回调事件
				priceStyle = 1, -- 价格显示类型
				limitBuyMaxCount = self.data.leftTimes == 0 and DataCenter.goFishingUtil.shopLimitBuyMaxNum or nil
			};
			Lua_WindowUtil.openWin("Lua_ShoppingGoodsWindow", Lua_WinParam.ACTION_OPEN, param);
		end
	end
end

function Lua_GoFishingShopItem:onSureBuy(itemId, selectNum)
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sBuyShopItem(self.data.id, self.data.shopType, selectNum, self.data.index);
end