-- 钓鱼-水族馆详情界面
Lua_GoFishingAquariumDetailWindow = class("Lua_GoFishingAquariumDetailWindow", Lua_Window);
function Lua_GoFishingAquariumDetailWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GoFishingAquariumDetailWindow";
	self.skinName = "GoFishingAquariumDetailWindow_skin";
	self.layer = MainWinDefine.NORMAL_TOP_LAYER;
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_GoFishingAquariumDetailWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.dragContainer = Lua_DragContainer.new(self.content, 636, 750, Lua_AxisDefine.Vertical);
	self.dragContainer:setCellSpacing(0, 9);
	self.dragContainer:setLocation(0, -40, 0);

	self:addLuaEvent("UPDATE_GOFISHING_AQUARIUM_INFO", self, self.updateAquariumDetailInfo);
end

function Lua_GoFishingAquariumDetailWindow:showWin(param)
	self:superCall("showWin", param);

	self:updateAquariumDetailInfo();
end

function Lua_GoFishingAquariumDetailWindow:updateAquariumDetailInfo()
	local aquariumList = DataCenter.goFishingData.aquariumList;
	local dic = {};
	for i = 1, #aquariumList do
		if dic[aquariumList[i].tag] == nil then
			dic[aquariumList[i].tag] = Array();
		end
		dic[aquariumList[i].tag]:add({tag = aquariumList[i].tag, index = aquariumList[i].index, fish = aquariumList[i].fish, showParam = self.showData});
	end

	self.dragContainer:clearList();
	for i = 1, #dic do
		dic[i]:sort("index", false);
		self.dragContainer:addSubContainer(Lua_GoFishingAquariumDetailTitleItem, dic[i]);
		for j = 1, dic[i]:getSize() do
			self.dragContainer:addSubContainer(Lua_GoFishingAquariumDetailInfoItem, dic[i][j]);
		end
	end
	self.dragContainer:updateChildPos();
end

function Lua_GoFishingAquariumDetailWindow:dispose()
	if self.dragContainer ~= nil then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end
	self:superCall("dispose");
end










Lua_GoFishingAquariumDetailTitleItem = class("Lua_GoFishingAquariumDetailTitleItem", Lua_DragContainerItem)
function Lua_GoFishingAquariumDetailTitleItem:ctor(p)
	self:superCall("ctor", p, "GoFishingAquariumDetailTitleItem_skin");
end

function Lua_GoFishingAquariumDetailTitleItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_GoFishingAquariumDetailTitleItem:setData(data)
	if data == nil then
		return;
	end

	local desStr = DataCenter.goFishingUtil:getTheTypeName(data[1].tag);
	local value = 0;
	for i = 1, data:getSize() do
		if data[i].fish.fishing and data[i].fish.fishing > 0 then
			value = value + 1;
		end
	end
	self.typeTxt.text = LanUtil.formateStr(794001, desStr, value, data:getSize());
end

function Lua_GoFishingAquariumDetailTitleItem:getWidth()
	return 636;
end

function Lua_GoFishingAquariumDetailTitleItem:getHeight()
	return self.itemBg.height;
end

function Lua_GoFishingAquariumDetailTitleItem:dispose()
	self:superCall("dispose");
end










Lua_GoFishingAquariumDetailInfoItem = class("Lua_GoFishingAquariumDetailInfoItem", Lua_DragContainerItem)
function Lua_GoFishingAquariumDetailInfoItem:ctor(p)
	self:superCall("ctor", p, "GoFishingAquariumDetailInfoItem_skin");
end

function Lua_GoFishingAquariumDetailInfoItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(-222, 10, 0);
	self.itemIcon:setScale(0.8, 0.8);

	self.stateBtn:addClickFuntion(self, self.onStateClick);
end

function Lua_GoFishingAquariumDetailInfoItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	if data.fish.fishing and data.fish.fishing > 0 then
		local tvo = Lua_ToolVo.createToolVo(data.fish.fishing);
		self.itemIcon:setData(tvo);
		self.nameTxt.text = tvo.name;

		local attrDic = {};
		for k,v in pairs(tvo.add_prop) do
			attrDic[k] = v * data.fish.length;
		end
		local attrArr = DataCenter.attributesUtil:getAttrArrByDic(attrDic);
		local propStr = "";
		for i = 1, attrArr:getSize() do
			propStr = propStr .. attrArr[i].show_name .. attrArr[i].showValue;
			if i ~= attrArr:getSize() then
				propStr = propStr .. "\n";
			end
		end
		self.propTxt.text = propStr;
		local showLength = tvo.max_length > tvo.length * data.fish.length and tvo.length * data.fish.length or tvo.max_length;
		self.lengthTxt.text = string.format("%.2f%s", showLength, "cm");
	else
		self.itemIcon:setData(nil);
		self.nameTxt:setLangValue(794002);
		self.propTxt:setLangValue(794003);
		self.lengthTxt:setLangValue(794004);
	end

	if type(data.showParam) == "number" then
		self.stateBtn:setLangValue(794005);
		self.stateBtn:setEnable(data.fish.fishing and data.fish.fishing > 0);
	else
		local sub_type = getConfig("item", data.showParam.fishing, "sub_type");
		if sub_type == data.tag then
			if data.fish.fishing and data.fish.fishing > 0 then
				self.stateBtn:setLangValue(794005);
				self.stateBtn:setEnable(true);
			else
				self.stateBtn:setLangValue(794006);
				self.stateBtn:setEnable(sub_type == data.tag);
			end
		end
		self.stateBtn:setEnable(sub_type == data.tag);
	end
end

function Lua_GoFishingAquariumDetailInfoItem:getWidth()
	return 636;
end

function Lua_GoFishingAquariumDetailInfoItem:getHeight()
	return self.itemBg.height;
end

function Lua_GoFishingAquariumDetailInfoItem:onStateClick(go)
	if type(self._data.showParam) == "number" then -- 出售
		self:onSellFun();
	else
		local sub_type = getConfig("item", self._data.showParam.fishing, "sub_type");
		if sub_type == self._data.tag then
			if self._data.fish.fishing and self._data.fish.fishing > 0 then -- 出售
				self:onSellFun();
			else -- 放入
				Lua_ProxyManager.getProxy("Lua_GoFishingProxy"):sDealWithFish(self._data.showParam.unique_id, 3, self._data.index);
				if Lua_WindowUtil.isWindowShowing("Lua_GoFishingGetResultWindow") then
					Lua_WindowUtil.openWin("Lua_GoFishingGetResultWindow", Lua_WinParam.ACTION_CLOSE);
				end
				if Lua_WindowUtil.isWindowShowing("Lua_GoFishingProtectionWindow") then
					Lua_MsgUtil.callFunc("UPDATE_GOFISHING_PROTECTION_SHOWORHIDE");
				end
				Lua_WindowUtil.openWin("Lua_GoFishingAquariumDetailWindow", Lua_WinParam.ACTION_CLOSE);
			end
		end
	end
end

function Lua_GoFishingAquariumDetailInfoItem:onSellFun()
	local tvo = Lua_ToolVo.createToolVo(self._data.fish.fishing);
	if tvo.color > 4 and not DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.GOFISHING_SELL) then
		local tipsData = {
			des = 794007,
			posY = 50,
			btnType = 1,
			neverTip = Lua_NeverTipDefine.GOFISHING_SELL,
			owner = self,
			sureFun = self.onSureSellFun
		};
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	else
		self:onSureSellFun();
	end
end

function Lua_GoFishingAquariumDetailInfoItem:onSureSellFun()
	Lua_ProxyManager.getProxy("Lua_GoFishingProxy"):sDealWithFish(self._data.fish.unique_id, 0, 0);
end

function Lua_GoFishingAquariumDetailInfoItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end