-- 钓鱼-渔场界面
Lua_GoFishingFisheryPanel = class("Lua_GoFishingFisheryPanel", Lua_DisplayObject);
function Lua_GoFishingFisheryPanel:ctor(p)
	self:superCall("ctor", p, "GoFishingFisheryPanel_skin");
end

function Lua_GoFishingFisheryPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.curIdx = DataCenter.goFishingData:getTheIndexByFisheryId(DataCenter.goFishingData.fisheryId);
	self.startIdx = 1;
	self.endIdx = DataCenter.goFishingUtil.fisheryArr:getSize();

	self.leftBtn:addClickFuntion(self, self.onLeftClick);
	self.rightBtn:addClickFuntion(self, self.onRightClick);
	self.operateBtn:addClickFuntion(self, self.onOperateClick);

	self:addLuaEvent("UPDATE_GOFISHING_FISHERY_INFO", self, self.updateFisheryInfo);
	self:onRequestOperate();
end

function Lua_GoFishingFisheryPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	if self.taskList then
		self.taskList:setContentRect(634, 300 + adaptHeight / 2);
		self.taskList:setLocation(0, -455 - adaptHeight / 4, 0);
	end
end

function Lua_GoFishingFisheryPanel:updateFisheryInfo(msg)
	self.curShowFisheryId = msg.fishery;
	self.isUnLock = msg.is_unlock == 1;

	local fisheryInfo = DataCenter.goFishingUtil:getTheFisheryInfo(msg.fishery);
	self.nameTxt.text = fisheryInfo.name;
	self.fisheryImg:setUrl(fisheryInfo.fishery_url);
	self.fisheryImg:setGray(msg.is_unlock ~= 1);

	local fisheryId = DataCenter.goFishingData.fisheryId;
	local isCanUnLock = true; -- 是否可解锁
	if msg.is_unlock == 1 then -- 已解锁
		isCanUnLock = false;
		self.desTxt.text = fisheryInfo.intro;
		self.desTxt:setEnable(true);
		self.operateBtn:setLangValue(794026);
		if self.taskList ~= nil then
			self.taskList:setEnable(false);
		end
	else
		local latestFisheryIdx = DataCenter.goFishingData:getTheIndexByFisheryId(msg.max_fishery); -- 当前解锁的最新的渔场
		self.desTxt:setLangValue(794027);
		self.desTxt:setEnable(self.curIdx - latestFisheryIdx > 1);
		self.operateBtn:setLangValue(794028);

		if self.taskList == nil then
			self.taskList = Lua_DragList.new(self.content, 634, 300 + self.adaptHeight / 2, Lua_AxisDefine.Vertical);
			self.taskList:setListCell(Lua_GoFishingFisheryItem, 634, 42, 1);
			self.taskList:setCellSpacing(0, 15);
			self.taskList:setLocation(0, -455 - self.adaptHeight / 4, 0);
		end
		self.taskList:setArrayData(msg.task_state);
		self.taskList:setEnable(self.curIdx - latestFisheryIdx == 1);

		if self.curIdx - latestFisheryIdx > 1 then
			isCanUnLock = false;
		else
			local obj;
			for i = 1, #msg.task_state do
				obj = msg.task_state[i];
				taskInfo = DataCenter.goFishingUtil:getFishTaskInfo(msg.task_state[i].key);
				if obj.value < taskInfo.process then
					isCanUnLock = false;
					break;
				end
			end
		end
	end
	self.tipsBg:setEnable(fisheryId == msg.fishery);
	self.tipsTxt:setEnable(fisheryId == msg.fishery);
	self.lockIcon:setEnable(msg.is_unlock ~= 1 and not isCanUnLock);
	self.operateBtn:setEnable((msg.is_unlock == 1 and fisheryId ~= msg.fishery) or (msg.is_unlock ~= 1 and isCanUnLock));
end

function Lua_GoFishingFisheryPanel:onRequestOperate()
	self.leftBtn:setEnable(self.curIdx > self.startIdx);
	self.rightBtn:setEnable(self.curIdx < self.endIdx);

	local fisheryId = DataCenter.goFishingUtil.fisheryArr[self.curIdx];
	Lua_ProxyManager.getProxy("Lua_GoFishingProxy"):sGoFishingFisheryInfo(fisheryId);
end

function Lua_GoFishingFisheryPanel:onLeftClick()
	if self.curIdx <= self.startIdx then
		return;
	end
	self.curIdx = self.curIdx - 1;
	self:onRequestOperate();
end

function Lua_GoFishingFisheryPanel:onRightClick()
	if self.curIdx >= self.endIdx then
		return;
	end
	self.curIdx = self.curIdx + 1;
	self:onRequestOperate();
end

function Lua_GoFishingFisheryPanel:onOperateClick(go)
	if self.isUnLock then -- 已解锁/前往
		-- 先播放云雾合并再拨开的特效，再请求
		Lua_ProxyManager.getProxy("Lua_GoFishingProxy"):sChangeGoFishingFishery(self.curShowFisheryId);
	else
		Lua_ProxyManager.getProxy("Lua_GoFishingProxy"):sUnLockFishery();
	end
end

function Lua_GoFishingFisheryPanel:dispose()
	if self.taskList ~= nil then
		self.taskList:dispose();
		self.taskList = nil;
	end
	self:superCall("dispose");
end










Lua_GoFishingFisheryItem = class("Lua_GoFishingFisheryItem", Lua_ListCell);
function Lua_GoFishingFisheryItem:ctor(p)
	self:superCall("ctor", p, "GoFishingFisheryItem_skin");
end

function Lua_GoFishingFisheryItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_GoFishingFisheryItem:setData(data)
	if data == nil then
		return;
	end
	local taskInfo = DataCenter.goFishingUtil:getFishTaskInfo(data.key);
	self.desTxt.text = taskInfo.name;
	self.progressTxt.text = LanUtil.formateStr(794029, data.value, taskInfo.process);
	self.completeIcon:setEnable(data.value >= taskInfo.process);
end

function Lua_GoFishingFisheryItem:dispose()
	self:superCall("dispose");
end